@@ -40,10 +40,10 @@ class BlobGeneratorCSV(CSVParser.CSVParser):
         super().__init__(filename)
 
         self.props_keys       = [x for x in self.header[1:]
-                                 if not x.startswith(CSVParser.CONTRAINTS_PREFIX)]
+                                 if not x.startswith(CSVParser.CONSTRAINTS_PREFIX)]
         self.props_keys       = [x for x in self.props_keys if x != BLOB_PATH]
         self.constraints_keys = [x for x in self.header[1:]
-                                 if x.startswith(CSVParser.CONTRAINTS_PREFIX)]
+                                 if x.startswith(CSVParser.CONSTRAINTS_PREFIX)]
 
     def getitem(self, idx):
 
