@@ -41,10 +41,10 @@ class ConnectionGeneratorCSV(CSVParser.CSVParser):
         super().__init__(filename)
 
         self.props_keys       = [x for x in self.header[3:]
-                                 if not x.startswith(CSVParser.CONTRAINTS_PREFIX)]
+                                 if not x.startswith(CSVParser.CONSTRAINTS_PREFIX)]
 
         self.constraints_keys = [x for x in self.header[3:]
-                                 if x.startswith(CSVParser.CONTRAINTS_PREFIX)]
+                                 if x.startswith(CSVParser.CONSTRAINTS_PREFIX)]
 
         self.src_class   = self.header[1].split("@")[0]
         self.src_key     = self.header[1].split("@")[1]
