@@ -61,9 +61,9 @@ class DescriptorGeneratorCSV(CSVParser.CSVParser):
         self.has_label = False
 
         self.props_keys       = [x for x in self.header[3:]
-                                 if not x.startswith(CSVParser.CONTRAINTS_PREFIX)]
+                                 if not x.startswith(CSVParser.CONSTRAINTS_PREFIX)]
         self.constraints_keys = [x for x in self.header[3:]
-                                 if x.startswith(CSVParser.CONTRAINTS_PREFIX)]
+                                 if x.startswith(CSVParser.CONSTRAINTS_PREFIX)]
 
     def getitem(self, idx):
 
