@@ -35,9 +35,9 @@ class DescriptorSetGeneratorCSV(CSVParser.CSVParser):
         super().__init__(filename)
 
         self.props_keys       = [x for x in self.header[4:]
-                                 if not x.startswith(CSVParser.CONTRAINTS_PREFIX)]
+                                 if not x.startswith(CSVParser.CONSTRAINTS_PREFIX)]
         self.constraints_keys = [x for x in self.header[4:]
-                                 if x.startswith(CSVParser.CONTRAINTS_PREFIX)]
+                                 if x.startswith(CSVParser.CONSTRAINTS_PREFIX)]
 
     def getitem(self, idx):
 
