@@ -1,7 +1,5 @@
-import os
-import sys
-import time
 import logging
+import json
 
 from aperturedb.Connector import Connector
 from aperturedb import ProgressBar
@@ -50,14 +48,23 @@ class Utils(object):
 
     def print_schema(self, refresh=False):
 
-        self.get_schema(refresh=refresh)
+        if refresh:
+            logger.warning("get_schema: refresh no longer needed.")
+            logger.warning("get_schema: refresh will be deprecated.")
+            logger.warning("Please remove 'refresh' parameter.")
+
+        self.get_schema()
         self.connector.print_last_response()
 
     def get_schema(self, refresh=False):
 
+        if refresh:
+            logger.warning("get_schema: refresh no longer needed.")
+            logger.warning("get_schema: refresh will be deprecated.")
+            logger.warning("Please remove 'refresh' parameter.")
+
         query = [{
             "GetSchema": {
-                "refresh": refresh,
             }
         }]
 
@@ -73,14 +80,79 @@ class Utils(object):
 
         return schema
 
-    def _create_index(self, index_type, class_name, property_key, property_type):
+    def _object_summary(self, name, object):
+
+        total_elements = object["matched"]
+
+        print(f"{name.ljust(20)}")
+        if "src" in object:
+            print(f"  {object['src']} ====> {object['dst']}")
+
+        print(f"  Total elements: {total_elements}")
+
+        p = object["properties"]
+
+        if p is None:
+            return
+
+        max = 0
+        for k in p:
+            max = len(k) if max < len(k) else max
+        max += 1
+
+        for k in p:
+            i = w = " "
+            i = "I" if p[k][1] else i
+
+            # Warning if there are some properties not present in all elements
+            w = "!" if p[k][0] != total_elements else w
+            # Warning if there is a property with "id" in the name not indexes
+            w = "!" if "id" in k and not p[k][1] else w
+            print(f"{i} {w} {p[k][2].ljust(8)} |"
+                  f" {k.ljust(max)} | {p[k][0]} "
+                  f"({int(p[k][0]/total_elements*100.0)}%)")
+
+    def summary(self):
+
+        r = self.get_schema()
+        s = json.loads(self.status())[0]["GetStatus"]
+        version = s["version"]
+        status  = s["status"]
+        info    = s["info"]
+
+        total_entities    = r["entities"]["returned"]
+        total_connections = r["entities"]["returned"]
+
+        entities_classes = [c for c in r["entities"]["classes"]]
+        connections_classes = [c for c in r["connections"]["classes"]]
+
+        total_images = self.count_images()
+
+        print(f"================== Summary ==================")
+        print(f"Database: {self.connector.host}")
+        print(f"Version: {version}")
+        print(f"Status:  {status}")
+        print(f"Info:    {info}")
+        print(f"Total entities types:    {total_entities}")
+        print(f"Total connections types: {total_connections}")
+        print(f"Total images:            {total_images}")
+        print(f"------------------ Entities -----------------")
+        for c in entities_classes:
+            self._object_summary(c, r["entities"]["classes"][c])
+
+        print(f"---------------- Connections ----------------")
+        for c in connections_classes:
+            self._object_summary(c, r["connections"]["classes"][c])
+
+        print(f"=============================================")
+
+    def _create_index(self, index_type, class_name, property_key):
 
         q = [{
             "CreateIndex": {
                 "index_type":    index_type,
                 "class":         class_name,
                 "property_key":  property_key,
-                "property_type": property_type
             }
         }]
 
@@ -116,15 +188,23 @@ class Utils(object):
 
         return True
 
-    def create_entity_index(self, class_name, property_key, property_type):
+    def create_entity_index(self, class_name, property_key, property_type=None):
 
-        return self._create_index("entity", class_name,
-                                  property_key, property_type)
+        if property_type is not None:
+            logger.warning(f"create_entity_index ignores 'property_type'")
+            logger.warning(f"'property_type' will be deprecated in the future")
+            logger.warning(f"Please remove 'property_type' parameter")
 
-    def create_connection_index(self, class_name, property_key, property_type):
+        return self._create_index("entity", class_name, property_key)
 
-        return self._create_index("connection", class_name,
-                                  property_key, property_type)
+    def create_connection_index(self, class_name, property_key, property_type=None):
+
+        if property_type is not None:
+            logger.warning(f"create_connection_index ignores 'property_type'")
+            logger.warning(f"'property_type' will be deprecated in the future")
+            logger.warning(f"Please remove 'property_type' parameter")
+
+        return self._create_index("connection", class_name, property_key)
 
     def remove_entity_index(self, class_name, property_key):
 
@@ -544,9 +624,7 @@ class Utils(object):
         if type not in ["entities", "connections"]:
             raise ValueError("Type must be either 'entities' or 'connections'")
 
-        # TODO we should probably set refresh=True so we always
-        # check the latest state, but it may take a long time to complete.
-        schema = self.get_schema(refresh=False)
+        schema = self.get_schema()
 
         try:
             indexed_props = schema[type]["classes"][class_name]["properties"]
@@ -604,6 +682,7 @@ class Utils(object):
             [{"DeleteVideo": cmd}],
             [{"DeleteImage": cmd}],
             [{"DeleteBlob": cmd}],
+            [{"DeletePolygon": cmd}],
             [{"DeleteEntity": cmd}],
         ]
 
