@@ -39,9 +39,9 @@ class VideoGeneratorCSV(CSVParser.CSVParser):
         self.check_video = check_video
 
         self.props_keys       = [x for x in self.header[1:]
-                                 if not x.startswith(CSVParser.CONTRAINTS_PREFIX)]
+                                 if not x.startswith(CSVParser.CONSTRAINTS_PREFIX)]
         self.constraints_keys = [x for x in self.header[1:]
-                                 if x.startswith(CSVParser.CONTRAINTS_PREFIX)]
+                                 if x.startswith(CSVParser.CONSTRAINTS_PREFIX)]
 
     def getitem(self, idx):
 
