@@ -6,26 +6,24 @@ from aperturedb import Utils
 from aperturedb import EntityLoader, ConnectionLoader
 from aperturedb import ImageLoader, BBoxLoader, BlobLoader
 from aperturedb import DescriptorSetLoader, DescriptorLoader
+import unittest
 
 
 class TestEntityLoader(TestBase):
     def setUp(self) -> None:
         db = self.create_connection()
         dbutils = Utils.Utils(db)
-        classes = ["_Image", "_Descriptor", "Person", "_BoundingBox"]
-        for c in classes:
-            # Assert that we have a clean slate to begin with.
-            self.assertEqual(dbutils.remove_entities(c), True)
-            self.assertEqual(dbutils.count_entities(c), 0)
+        self.assertTrue(dbutils.remove_all_objects(), True)
 
+    @unittest.skip("This is going to be deleted.")
     def test_Loader(self):
 
         db = self.create_connection()
         dbutils = Utils.Utils(db)
 
-        dbutils.create_entity_index("_Image",      "id", "integer")
-        dbutils.create_entity_index("_Descriptor", "id", "integer")
-        dbutils.create_entity_index("Person",      "id", "integer")
+        dbutils.create_entity_index("_Image",      "id")
+        dbutils.create_entity_index("_Descriptor", "id")
+        dbutils.create_entity_index("Person",      "id")
 
         # Insert Person Nodes
         in_csv_file = "./input/persons.adb.csv"
